==> elemental2-dom-1.2.3.jar: elemental2/dom/PageTransitionEvent.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsProperty;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;
import jsinterop.base.JsPropertyMap;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class PageTransitionEvent extends Event {
  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface PageTransitionEventEventInitDictType {
    @JsOverlay
    static PageTransitionEvent.PageTransitionEventEventInitDictType create() {
      return Js.uncheckedCast(JsPropertyMap.of());
    }

    @JsProperty
    boolean isPersisted();

    @JsProperty
    void setPersisted(boolean persisted);
  }

  public boolean persisted;

  public PageTransitionEvent(
      String type, PageTransitionEvent.PageTransitionEventEventInitDictType eventInitDict) {
    // This super call is here only for the code to compile; it is never executed.
    super((String) null, (EventInit) null);
  }

  public PageTransitionEvent(String type) {
    // This super call is here only for the code to compile; it is never executed.
    super((String) null, (EventInit) null);
  }

  public native void initPageTransitionEvent(
      String typeArg, boolean canBubbleArg, boolean cancelableArg, Object persistedArg);
}

==> elemental2-dom-1.3.2.jar: elemental2/dom/PageTransitionEvent.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsProperty;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;
import jsinterop.base.JsPropertyMap;
import org.jspecify.annotations.Nullable;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class PageTransitionEvent extends Event {
  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface PageTransitionEventEventInitDictType {
    @JsOverlay
    static PageTransitionEvent.PageTransitionEventEventInitDictType create() {
      return Js.uncheckedCast(JsPropertyMap.of());
    }

    @JsProperty
    boolean isPersisted();

    @JsProperty
    void setPersisted(boolean persisted);
  }

  public boolean persisted;

  public PageTransitionEvent(
      String type, PageTransitionEvent.PageTransitionEventEventInitDictType eventInitDict) {
    // This super call is here only for the code to compile; it is never executed.
    super((String) null, (@Nullable EventInit) null);
  }

  public PageTransitionEvent(String type) {
    // This super call is here only for the code to compile; it is never executed.
    super((String) null, (@Nullable EventInit) null);
  }

  public native void initPageTransitionEvent(
      String typeArg, boolean canBubbleArg, boolean cancelableArg, @Nullable Object persistedArg);
}
